"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const actions_1 = require("./..");
const routeList_1 = require("../../routeList");
const rnSplashScreen_1 = tslib_1.__importDefault(require("../../polyfills/rnSplashScreen"));
const errors_1 = require("../../lib/errors");
exports.showErrorScreen = (error) => dispatch => {
    const appError = error.constructor === errors_1.AppError
        ? error
        : new errors_1.AppError(errors_1.ErrorCode.Unknown, error);
    return dispatch(actions_1.navigationActions.navigate({
        routeName: routeList_1.routeList.Exception,
        params: {
            returnTo: appError.navigateTo,
            error: appError,
        },
    }));
};
exports.initApp = (dispatch, getState, backendMiddleware) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    try {
        yield backendMiddleware.initStorage();
        const storedSettings = yield backendMiddleware.storageLib.get.settingsObject();
        /**
         * @dev Until German and Dutch terms are polished, only English is used.
         * previous code:
         * if (storedSettings.locale) I18n.locale = storedSettings.locale
         * else storedSettings.locale = I18n.locale
         */
        // storedSettings.locale = I18n.locale
        rnSplashScreen_1.default.hide();
        return dispatch(exports.loadSettings(storedSettings));
    }
    catch (e) {
        return dispatch(exports.showErrorScreen(new errors_1.AppError(errors_1.ErrorCode.WalletInitFailed, e, routeList_1.routeList.Landing)));
    }
});
exports.loadSettings = (settings) => ({
    type: 'LOAD_SETTINGS',
    value: settings,
});
exports.setLocale = (locale) => (dispatch, getState, backendMiddleware) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    // await backendMiddleware.storageLib.store.setting(settingKeys.locale, locale)
    // I18n.locale = locale
    // dispatch({ type: 'SET_LOCALE', value: locale })
    // we need to reset the navigator so that all screens are re-rendered with the
    // new locale
    return dispatch(actions_1.navigationActions.navigatorReset());
});
