import { Notification, NotificationFilter } from "../../lib/notifications";
import { RootState } from '../../reducers';
/**
 * @description Add a notification to the queue, to be displayed at an
 *              appropriate time in the future, or right away if possible
 */
export declare const scheduleNotification: (notification: Notification) => import("redux-thunk").ThunkAction<import("redux").AnyAction | Promise<void | import("redux").AnyAction>, RootState, import("../../backendMiddleware").BackendMiddleware, import("redux").AnyAction>;
/**
 * @description Invoke the notification interact callback and remove it from
 *              queue and active. Should be dispatched on interaction with the
 *              notification's "call to action" button
 *
 */
export declare const invokeInteract: (notification: Notification) => import("redux-thunk").ThunkAction<import("redux").AnyAction | Promise<void | import("redux").AnyAction>, RootState, import("../../backendMiddleware").BackendMiddleware, import("redux").AnyAction>;
/**
 * @description Invoke the notification dismiss callback and remove it from
 *              queue and active. Should be dispatched on interaction with the
 *              notification's "dismiss" button
 */
export declare const invokeDismiss: (notification: Notification) => import("redux-thunk").ThunkAction<import("redux").AnyAction | Promise<void | import("redux").AnyAction>, RootState, import("../../backendMiddleware").BackendMiddleware, import("redux").AnyAction>;
/**
 * @description Clear all notifications from queue and from active
 */
export declare const clearAllNotifications: () => import("redux-thunk").ThunkAction<import("redux").AnyAction | Promise<void | import("redux").AnyAction>, RootState, import("../../backendMiddleware").BackendMiddleware, import("redux").AnyAction>;
/**
 * @description Remove a notification from queue
 *              Should generally not need to be dispatched directly, but is
 *              exported for testing purposes.
 *              No callbacks are invoked.
 */
export declare const removeNotification: (notification: Notification, clearActive?: boolean) => import("redux-thunk").ThunkAction<import("redux").AnyAction | Promise<void | import("redux").AnyAction>, RootState, import("../../backendMiddleware").BackendMiddleware, import("redux").AnyAction>;
/**
 * @description Set the active notification filter
 *              see NotificationFilter in src/lib/notifications
 *              only notifications matching the filter will be considered for
 *              the "active" notification
 */
export declare const setActiveNotificationFilter: (filter: NotificationFilter) => import("redux-thunk").ThunkAction<import("redux").AnyAction | Promise<void | import("redux").AnyAction>, RootState, import("../../backendMiddleware").BackendMiddleware, import("redux").AnyAction>;
