import { AppError } from "./errors";
interface NotificationMessage {
    title: string;
    message?: string;
}
/**
 * A notification is either dismissible or not
 * if it is dismissible it can also optionally have
 * - a label (for the dismiss button)
 * - a timeout (to auto-dismiss)
 * - a callback
 */
export interface NotificationDismiss {
    dismiss?: false | {
        label?: string;
        timeout?: number;
        onDismiss?: (...args: any) => void;
    };
}
/**
 * A notification may have a call to action button,
 * with a label and an onInteract callback
 * It is not possible to simply specify a boolean, because if an interaction is
 * expected then a callback and label are required.
 */
interface NotificationInteract {
    interact?: {
        label: string;
        onInteract: (...args: any) => void | boolean | Promise<void | boolean>;
    };
}
/**
 * The payload is either a message if the type is warning or info, or an error
 * if the type is error.
 */
declare type NotificationPayload = {
    type: NotificationType.warning | NotificationType.info;
    error?: AppError;
} & NotificationMessage;
interface NotificationBase {
    id: string;
    type: NotificationType;
}
export declare type Notification = NotificationBase & NotificationInteract & NotificationDismiss & NotificationPayload;
export declare enum NotificationFilter {
    none = 0,
    all = 1,
    onlyDismissible = 2
}
export declare enum NotificationType {
    error = "error",
    info = "info",
    warning = "warning"
}
export declare const createInfoNotification: (overrides: Partial<NotificationBase> & NotificationInteract & NotificationDismiss & NotificationMessage) => Notification;
export declare const createWarningNotification: (overrides: Partial<NotificationBase> & NotificationInteract & NotificationDismiss & NotificationMessage) => Notification;
export declare const createStickyNotification: (overrides: Partial<NotificationBase> & NotificationInteract & NotificationDismiss & NotificationMessage) => Notification;
export {};
