"use strict";
/**
 * This migration re-encrypts the encryptedEntropy in the wallet database using
 * the jolocom-lib (which uses node crypto) instead of the previously used
 * crypto-js dependency
 */
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const cryptojs_1 = tslib_1.__importDefault(require("./../../compat/cryptojs"));
const keychain_1 = require("../../../polyfills/keychain");
const jolocomLib_1 = require("./../../compat/jolocomLib");
const getMasterKeys = (queryRunner) => queryRunner.query('SELECT encryptedEntropy FROM master_keys;');
class ReencryptSeed1567674609659 {
    up(queryRunner) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            let password;
            try {
                password = yield new keychain_1.KeyChain().getPassword();
            }
            catch (e) {
                // This may fail if the application was uninstalled and reinstalled, as
                // the android keystore is cleared on uninstall, but the database may
                // still remain (and is probably pre-migrations, given that this is
                // running in the first place). In that case we take no action, and let
                // the app init code handle things
                return;
            }
            const entries = yield getMasterKeys(queryRunner);
            return Promise.all(entries.map(({ encryptedEntropy }) => {
                // If the seed is base64 encoded, it must be migrated (CryptoJS encoded base64)
                // If the seed is hex encoded, it must not be migrated (The newer version of the lib use HEX)
                if (/^[0-9a-fA-F]*$/.test(encryptedEntropy))
                    return;
                const decrypted = cryptojs_1.default.AES.decrypt(encryptedEntropy, password).toString();
                const reencrypted = jolocomLib_1.encryptWithLib3(Buffer.from(decrypted, 'hex'), password).toString('hex');
                return queryRunner.query(`UPDATE master_keys ` +
                    `SET encryptedEntropy = '${reencrypted}' ` +
                    `WHERE encryptedEntropy = '${encryptedEntropy}'`);
            }));
        });
    }
    down(queryRunner) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            throw new Error("There's no going back");
            // because why?
        });
    }
}
exports.ReencryptSeed1567674609659 = ReencryptSeed1567674609659;
