"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const keychain_1 = require("../../../polyfills/keychain");
const jolocomLib_1 = require("../../compat/jolocomLib");
const getMasterKeys = (queryRunner) => queryRunner.query('SELECT encryptedEntropy FROM master_keys;');
// Migration for JolocomLib 3.0.0 to JolocomLib 4.0.0.
class Lib3To41580937907601 {
    up(queryRunner) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            let pass;
            try {
                pass = yield new keychain_1.KeyChain().getPassword();
            }
            catch (e) {
                return;
            }
            const entries = yield getMasterKeys(queryRunner);
            return Promise.all(entries.map(({ encryptedEntropy }) => tslib_1.__awaiter(this, void 0, void 0, function* () {
                const decrypted = jolocomLib_1.decryptWithLib3(Buffer.from(encryptedEntropy, 'hex'), pass);
                const reencrypted = yield jolocomLib_1.encryptWithLib4(decrypted, pass);
                return queryRunner.query(`UPDATE master_keys ` +
                    `SET encryptedEntropy = '${reencrypted.toString('hex')}' ` +
                    `WHERE encryptedEntropy = '${encryptedEntropy}'`);
            })));
        });
    }
    down(queryRunner) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            let pass;
            try {
                pass = yield new keychain_1.KeyChain().getPassword();
            }
            catch (e) {
                return;
            }
            const entries = yield getMasterKeys(queryRunner);
            return Promise.all(entries.map(({ encryptedEntropy }) => {
                const decrypted = jolocomLib_1.decryptWithLib4(Buffer.from(encryptedEntropy, 'hex'), pass);
                const reencrypted = jolocomLib_1.encryptWithLib3(decrypted, pass).toString('hex');
                return queryRunner.query(`UPDATE master_keys ` +
                    `SET encryptedEntropy = '${reencrypted}' ` +
                    `WHERE encryptedEntropy = '${encryptedEntropy}'`);
            }));
        });
    }
}
exports.Lib3To41580937907601 = Lib3To41580937907601;
