import { ConnectionOptions, Connection } from 'typeorm';
import { PersonaEntity, CacheEntity, InteractionTokenEntity } from "./entities";
import { SignedCredential } from 'jolocom-lib/js/credentials/signedCredential/signedCredential';
import { CredentialOfferMetadata, CredentialOfferRenderInfo } from 'jolocom-lib/js/interactionTokens/interactionTokens.types';
import { IdentitySummary } from '../../actions/sso/types';
import { DidDocument } from 'jolocom-lib/js/identity/didDocument/didDocument';
import { JWTEncodable, JSONWebToken } from 'jolocom-lib/js/interactionTokens/JSONWebToken';
interface PersonaAttributes {
    did: string;
    controllingKeyPath: string;
}
interface EncryptedSeedAttributes {
    encryptedEntropy: string;
    timestamp: number;
}
/**
 * @todo IdentitySummary is a UI type, which can always be
 * derived from a DID Doc and Public Profile.
 * Perhaps that's what we should store instead, since those
 * are more generic and can be reused.
 */
export declare class Storage {
    private connection;
    private connectionPromise;
    private config;
    store: {
        setting: (key: string, value: any) => Promise<void>;
        persona: (args: PersonaAttributes) => Promise<void>;
        verifiableCredential: (vCred: SignedCredential) => Promise<void>;
        encryptedSeed: (args: EncryptedSeedAttributes) => Promise<void>;
        credentialMetadata: (metadata: CredentialMetadataSummary) => Promise<CacheEntity>;
        issuerProfile: (issuer: IdentitySummary) => Promise<CacheEntity>;
        didDoc: (doc: DidDocument) => Promise<CacheEntity>;
        interactionToken: (token: JSONWebToken<JWTEncodable>) => Promise<InteractionTokenEntity>;
    };
    get: {
        settingsObject: () => Promise<{
            [key: string]: any;
        }>;
        setting: (key: string) => Promise<any>;
        persona: (query?: object | undefined) => Promise<PersonaEntity[]>;
        verifiableCredential: (query?: object | undefined) => Promise<SignedCredential[]>;
        attributesByType: (type: string[]) => Promise<{
            type: string[];
            results: {
                verification: string;
                values: string[];
                fieldName: string;
            }[];
        }>;
        vCredentialsByAttributeValue: (attribute: string) => Promise<SignedCredential[]>;
        encryptedSeed: () => Promise<string | null>;
        credentialMetadata: (credential: SignedCredential) => Promise<any>;
        publicProfile: (did: string) => Promise<IdentitySummary>;
        didDoc: (did: string) => Promise<DidDocument | undefined>;
        interactionTokens: (attrs: {
            nonce?: string | undefined;
            type?: string | undefined;
            issuer?: string | undefined;
        }) => Promise<JSONWebToken<JWTEncodable>[]>;
    };
    delete: {
        verifiableCredential: (id: string) => Promise<void>;
    };
    initConnection: () => Promise<Connection>;
    constructor(config: ConnectionOptions);
    resetDatabase(): Promise<void>;
    private createConnectionIfNeeded;
    private getSettingsObject;
    private getSetting;
    private saveSetting;
    private getPersonas;
    private getVCredential;
    private getAttributesByType;
    private getVCredentialsForAttribute;
    private getEncryptedSeed;
    private storePersonaFromJSON;
    private storeEncryptedSeed;
    private storeVClaim;
    private deleteVCred;
}
export interface CredentialMetadata {
    type: string;
    renderInfo: CredentialOfferRenderInfo;
    metadata: CredentialOfferMetadata;
}
export interface CredentialMetadataSummary extends CredentialMetadata {
    issuer: IdentitySummary;
}
export {};
