"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const types_1 = require("jolocom-lib/js/interactionTokens/types");
const isValid = (p) => p.then(_ => true).catch(_ => false);
exports.isCredReq = (t) => typeof t !== 'undefined' &&
    t.interactionType === types_1.InteractionType.CredentialRequest;
exports.isCredOfferReq = (t) => typeof t !== 'undefined' &&
    t.interactionType === types_1.InteractionType.CredentialOfferRequest;
exports.consumeCredentialResponse = (bemw) => (token) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    // realistically, all of this should probably happen before the token is
    // added to the history, to avoid polluting valid interaction histories with invalid tokens
    const history = yield bemw.storageLib.get.interactionTokens({
        nonce: token.nonce,
    });
    if (history.length != 2)
        throw new Error('bad interaction');
    const request = history.find(t => t.interactionType === types_1.InteractionType.CredentialRequest);
    if (!exports.isCredReq(request))
        throw new Error('bad interaction');
    return ((yield isValid(bemw.identityWallet.validateJWT(token, request))) &&
        (yield token.interactionToken.satisfiesRequest(request.interactionToken)));
});
exports.consumeCredentialOfferResponse = (bemw) => (token) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    // realistically, all of this should probably happen before the token is
    // added to the history, to avoid polluting valid interaction histories with invalid tokens
    const history = yield bemw.storageLib.get.interactionTokens({
        nonce: token.nonce,
    });
    if (history.length != 3)
        throw new Error('bad interaction');
    const request = history.find(t => t.interactionType === types_1.InteractionType.CredentialOfferRequest);
    if (exports.isCredOfferReq(request))
        throw new Error('bad interaction');
    return yield bemw.identityWallet.validateJWT(token, request);
});
